/***********************************************************************
*
* Copyright (c) 2021-2022 Barbara Geller and Ansel Sermersheim
*
* This example is free software, released under the BSD 2-Clause license.
* For license details refer to LICENSE provided with this project.
*
* CopperSpice is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
*
* https://opensource.org/licenses/BSD-2-Clause
*
***********************************************************************/

#include <QtCore>
#include <QtGui>

class MainWindow : public QMainWindow
{
 public:
   MainWindow();

 private:
   void showAboutJournal();
};

MainWindow::MainWindow()
{
   setMinimumSize(700, 500);

   QWidget *centralWidget = new QWidget(this);
   setCentralWidget(centralWidget);

   // *
   QAction *openFile = new QAction("Open", this);
   openFile->setShortcuts(QKeySequence::Open);
   openFile->setIcon(QIcon("../file_open.png"));

   QAction *closeFile = new QAction("Close", this);
   closeFile->setIcon(QIcon("../file_close.png"));

   QAction *saveFile = new QAction("Save", this);
   saveFile->setShortcuts(QKeySequence::Save);
   saveFile->setIcon(QIcon("../file_save.png"));

   QAction *exit = new QAction("Exit", this);
   connect(exit, &QAction::triggered, this, &QWidget::close);

#ifdef Q_OS_WIN
   exit->setShortcut(QKeySequence(Qt::AltModifier | Qt::Key_F4));
#else
   exit->setShortcuts(QKeySequence::Quit);
#endif

   // *
   QAction *undo = new QAction("Undo", this);
   undo->setIcon(QIcon("../undo.png"));

   QAction *redo = new QAction("Redo", this);
   redo->setIcon(QIcon("../redo.png"));

   QAction *cut = new QAction("Cut", this);
   cut->setIcon(QIcon("../cut.png"));

   QAction *copy = new QAction("Copy", this);
   copy->setIcon(QIcon("../copy.png"));

   QAction *paste = new QAction("Paste", this);
   paste->setIcon(QIcon("../paste.png"));

   QAction *about = new QAction("About Journal", this);
   connect(about, &QAction::triggered, this, &MainWindow::showAboutJournal);

   QMenu *fileMenu = menuBar()->addMenu("File");
   fileMenu->addAction(openFile);
   fileMenu->addAction(closeFile);
   fileMenu->addAction(saveFile);
   fileMenu->addSeparator();
   fileMenu->addAction(exit);

   QMenu *editMenu = menuBar()->addMenu("Edit");
   editMenu->addAction(undo);
   editMenu->addAction(redo);
   editMenu->addSeparator();
   editMenu->addAction(cut);
   editMenu->addAction(copy);
   editMenu->addAction(paste);

   QMenu *helpMenu = menuBar()->addMenu("Help");
   helpMenu->addAction(about);

   // *
   QToolBar *fileToolBar = addToolBar("Uncheck to turn off tool bar for File Menu");
   fileToolBar->addAction(openFile);
   fileToolBar->addAction(closeFile);
   fileToolBar->addAction(saveFile);

   QToolBar *editToolBar = addToolBar("Edit Menu");
   editToolBar->addAction(undo);
   editToolBar->addAction(redo);
   editToolBar->addSeparator();
   editToolBar->addAction(cut);
   editToolBar->addAction(copy);
   editToolBar->addAction(paste);

   // *
   QPushButton *pb_close = new QPushButton();
   pb_close->setText("Close");

   QHBoxLayout *layout = new QHBoxLayout();
   layout->addStretch();
   layout->addWidget(pb_close);
   layout->addStretch();

   centralWidget->setLayout(layout);

   connect(pb_close, &QPushButton::clicked, this, &QWidget::close);
}

void MainWindow::showAboutJournal()
{
   QMessageBox::about(this, "About Journal",
      "Text which typically contains the Developer or Organization Name, Version Number, and Copyright details.");
}

int main(int argc, char *argv[])
{
   QApplication app(argc, argv);

   MainWindow *window = new MainWindow();
   window->show();

   return app.exec();
}
